<?php
/*
Plugin Name: XView
Plugin URI: 
Description: XViewと連携し、分析データのコメントやグラフを表示する
Version: 0.8
Author: Toshiaki Endo
Author URI: https://www.generation.ne.jp/
License: MIT
License URI: 
*/

class xview {
    function __construct() {
        add_action( 'admin_menu', array( $this, 'add_option_pages' ) );
        add_action( 'add_meta_boxes', array( $this, 'xview_meta_box_output' ) );
        
        // 更新ボタンが押された時カスタムフィールドを更新
        add_action( 'save_post', array( $this, 'save_custom_field' ) );
        
        //
        add_shortcode( 'xview', array( $this, 'xview_view' ) );
        
        //
        add_action( 'wp_head', array( $this, 'style_select' ) );
    }

    //
    function xview_meta_box_output() {
        add_meta_box( 'xviewmetabox', 'XView選択', array( $this, 'xview_meta_box' ), 'post', 'advanced', 'default' );
    }

    // カスタムフィールドの保存
    function save_custom_field( $post_id ) {
        // 編集リスト
        $sid = $_POST['sid'];
        update_post_meta( $post_id, '_sid', $sid );
        
        // json
        $xjson = $_POST['xview_json'];
        update_post_meta( $post_id, '_xview_json', $xjson );
    }

    // メタボックスの描画
    function xview_meta_box() {
        global $post;
        // JSの登録
        wp_register_script( 'xview.js', plugins_url( 'js/xview.js', __FILE__ ), false, null, true );
        // JSの呼び出し
        wp_enqueue_script( 'xview.js' );
        
        wp_enqueue_style( 'admin_print_styles', plugins_url( '/css/style.css' , __FILE__ ) );

        // 登録済みのカスタムフィールド情報を取得
        $sid   = get_post_meta( $post->ID, '_sid', true );
        $xjson = get_post_meta( $post->ID, '_xview_json', true );

        // XVView設定で設定されている設定情報を取得する
        $opt_server = get_option('xview_server');
        $opt_mail   = get_option('xview_mail');
        
        $xview_server = isset($opt_server['text']) ? $opt_server['text']: null;
        $xview_mail   = isset($opt_mail['text']) ? $opt_mail['text']: null;

        $iright = plugins_url( '/img/right.png', __FILE__ );
        $ileft  = plugins_url( '/img/left.png', __FILE__ );

        if ( substr( $xview_server, -1 ) != '/' ) {
            $xview_server = $xview_server . '/';
        }

        // 編集リストをXviewから取得
        $result = file_get_contents($xview_server.'editbox.php?direct=getedit&mail='.$xview_mail.'&callback=xview_wp_func');
        $result = mb_convert_encoding($result, 'UTF8', 'ASCII,JIS,UTF-8,EUC-JP,SJIS-WIN');


        $dsp_html = "";
        if ( strlen($result) > 0 ) {
            // jsonpからjsonに置換
            $result = substr($result, 0, -1);
            $result = substr($result, 14);
            // jsonをパースする
            $obj = json_decode($result, true);
            if ($obj === NULL) {
                return;
            }

            if ($obj['RESULT'] != "Success" ) {
                return;
            }

            if ( $sid <> '' ) {
                $dsp_html .= "<option value='' disabled>選択して下さい</option>";
            } else {
                $dsp_html .= "<option value=''>選択して下さい</option>";
            }

            foreach ($obj['EDITLIST'] as $id => $rec) {
                if ( $sid <> '' ) {
                    if ( $sid == $rec['EDITNO'] ) {
                        $dsp_html .= "<option value='" . $rec['EDITNO'] . "' selected>" . $rec['EDITNAME'] . "</option>\n";
                    } else {
                        $dsp_html .= "<option value='" . $rec['EDITNO'] . "' disabled>" . $rec['EDITNAME'] . "</option>\n";
                    }
                } else {
                    $dsp_html .= "<option value='" . $rec['EDITNO'] . "'>" . $rec['EDITNAME'] . "</option>\n";
                }
            }

            wp_localize_script('xview.js', 'xview', array(server => $xview_server, mail => $xview_mail, icon_right => $iright, icon_left => $ileft, xjson => $xjson));
        }

?>
        <div class="wrap">
            <div>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row" style="20%"><label for="inputtext">編集リスト</label></th>
                        <td id="select_area" style="width: 80%">
                            <select id="sid" name="sid">
<?php
        echo $dsp_html;
?>
                            </select>
                        </td>
                    </tr>
                </table>
                <table class="form-table">
                    <tr id="xview_area" valign="top">
                    </tr>
                </table>
            </div>
            <div><input type="hidden" id="xview_json" name="xview_json"></div>
        </div><!-- /.wrap -->
<?php
    }



    function add_option_pages() {
        // 設定メニュー下に「XView用設定」メニューを追加
        add_submenu_page('options-general.php', 'XView設定', 'XView用設定', 'level_8', __FILE__, array($this, 'show_xview_option_page') );
    }

    function show_xview_option_page() {
        $up_flug = '0';
        //$_POST['xview_server'])があったら保存
        if ( isset($_POST['xview_server'])) {
            check_admin_referer('shoptions');
            $opt_server = wp_unslash($_POST['xview_server']);
            update_option('xview_server', $opt_server);
            $up_flug = '1';
        }
        //$_POST['xview_mail'])があったら保存
        if ( isset($_POST['xview_mail'])) {
            check_admin_referer('shoptions');
            $opt_mail = wp_unslash($_POST['xview_mail']);
            update_option('xview_mail', $opt_mail);
            $up_flug = '1';
        }
        if ( $up_flug == '1' ) {
?>
            <div class="updated fade"><p><strong><?php _e('Options saved.'); ?></strong></p></div>
<?php
        }
?>
        <div class="wrap">
        <div id="icon-options-general" class="icon32"><br /></div><h2>XView設定</h2>
            <form action="" method="post">
<?php
    wp_nonce_field('shoptions');
    $opt_mail = get_option('xview_mail');
    $xview_address = isset($opt_mail['text']) ? $opt_mail['text']: null;
    $opt_server = get_option('xview_server');
    $xview_server = isset($opt_server['text']) ? $opt_server['text']: null;
?> 
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row"><label for="inputtext">XViewサーバーアドレス</label></th>
                        <td><input name="xview_server[text]" type="text" id="inputtext" value="<?php  echo $xview_server ?>" class="regular-text" /></td>
                    </tr>
                    <tr valign="top">
                        <th scope="row"><label for="inputtext">E-Mailアドレス</label></th>
                        <td><input name="xview_mail[text]" type="text" id="inputtext" value="<?php  echo $xview_address ?>" class="regular-text" /></td>
                    </tr>
                </table>
                <p class="submit"><input type="submit" name="Submit" class="button-primary" value="変更を保存" /></p>
            </form>
        </div><!-- /.wrap -->
<?php
    }
    
    // ショットコードからコンテンツに変換する
    function xview_view( $atts ) {
        global $post;
        
        // XVView設定で設定されている設定情報を取得する
        $opt_server = get_option('xview_server');
        $xview_server = isset($opt_server['text']) ? $opt_server['text']: null;

        if ( substr( $xview_server, -1 ) != '/' ) {
            $xview_server = $xview_server . '/';
        }

        // デフォルトのパラメータを設定
        $default_atts = array(
                        'fig' => '0',
                        'pos' => 'right'
                        );

        // 指定された属性を取得（無ければデフォルトセット）
        extract( shortcode_atts( $default_atts, $atts ) );
        
        $tmp_fig = (int)$fig;
        $tmp_pos = $pos;

        // カスタムフィールドからjson文字列を取得
        $json_str = get_post_meta($post->ID, '_xview_json', true);

        // json文字列をデコードしてjson型に変換
        $xview_json = json_decode($json_str, true);
        
        $xview_title = $xview_json[$tmp_fig]['TITLE'];
        $xview_desc  = $xview_json[$tmp_fig]['DESCRIPTION'];
        $xview_img   = $xview_json[$tmp_fig]['IMAGE'];
        $xview_url   = $xview_server . $xview_json[$tmp_fig]['URL'];
        $xview_pos   = $xview_json[$tmp_fig]['pos'];

        if ( $xview_pos == "right" ) {
            $xview_class = "xview_right";
        } elseif ( $xview_pos == "left" ) {
            $xview_class = "xview_left";
        } else {
            $xview_class = "xview_wide";
            $xview_width = "100%";
            $xview_height = "1--%";
        }

        // 戻り値の設定
        $ret_html  = "";

        $ret_html  = "<div class='xview_box'>\n";
        $ret_html .= "    <h2>".$xview_title."</h2>\n";
        $ret_html .= "    <div class='xview_mess'>\n";
        $ret_html .= "        <a href='".$xview_url."'><img src='".$xview_img."' class='".$xview_class."'></a>\n";
        $ret_html .= "        <p>".$xview_desc."</p>\n";
        $ret_html .= "    </div>\n";
        $ret_html .= "</div>\n";

        return $ret_html;
    }

    function style_select() {
        $tag_str = "";
        $singular_css = plugins_url( 'css/style.css', __FILE__ );

//        if ( is_singular() ) {
            $tag_str = "<link rel=\"stylesheet\" href=\"" . $singular_css . "\" type=\"text/css\" media=\"screen\" />\n";
//            $tag_str = "テスト1";
//        } else {
//            $tag_str = "テスト2";
//        }

        echo $tag_str;
    }
}
$xview_join = new xview;